# -*- coding: utf-8 -*-

from random import choice
from faker.providers import BaseProvider, ElementsType

localized = True


class BaseEnergySupplier(BaseProvider):
    control_letters: ElementsType[str] = (
        "T", "R", "W", "A", "G", "M", "Y", "F", "P", "D", "X", "B", "N", "J", "Z", "S", "Q", "V", "H", "L", "C", "K", "E")

    def calculate_control_code(self, cups16):
        cups16_mod = int(cups16) % 529
        quotient = int(cups16_mod / 23)
        remainder = cups16_mod % 23
        return self.control_letters[quotient] + self.control_letters[remainder]

    def evaluate_type(self, point_type, country_code, cups16, control):
        if point_type == "F":
            return country_code + cups16 + control + "1F"
        elif point_type == "P":
            return country_code + cups16 + control + "1P"
        elif point_type == "C":
            return country_code + cups16 + control + "1C"
        elif point_type == "X":
            return country_code + cups16 + control + "1X"
        elif point_type is None:
            return country_code + cups16 + control
        else:
            return None



# -*- coding: utf-8 -*-

import random
from random import choice
from re import match

from energy_supplier import BaseEnergySupplier
from faker.providers import ElementsType

localized = True


class PowerEnergySupplier(BaseEnergySupplier):
    distributor: ElementsType[str] = \
        (
            "0023",
            "0024",
            "0029",
            "0288",
            "0363",
            "0396",
            "0021",
            "0022",
            "0390",
            "0397",
            "0026",
            "0027"
        )

    country_code = "ES"

    def power_code(self, point_type=None):
        """Returns a random code based on CUPS https://es.wikipedia.org/wiki/C%C3%B3digo_Unificado_de_Punto_de_Suministro"""

        cups16 = self.distributor[random.randrange(0, len(self.distributor) - 1)] + str(self.numerify("############"))
        control = self.calculate_control_code(cups16)
        return self.evaluate_type(point_type, self.country_code, cups16, control)


class GasEnergySupplier(BaseEnergySupplier):
    distributor: ElementsType[str] = \
        (
            "0201",
            "0203",
            "0210",
            "0211",
            "0212",
            "0213",
            "0214",
            "0219",
            "0229",
            "0204",
            "0205",
            "0206",
            "0208",
            "0209",
            "0225",
            "0207",
            "0217",
            "0218",
            "0220",
            "0221",
            "0222",
            "0223",
            "0224",
            "0226",
            "0227",
            "0230",
            "0228",
            "0234",
            "0236"
        )

    country_code = "ES"

    def gas_code(self, point_type=None):
        """Returns a random code based on CUPS https://es.wikipedia.org/wiki/C%C3%B3digo_Unificado_de_Punto_de_Suministro"""

        cups16 = self.distributor[random.randrange(0, len(self.distributor) - 1)] + str(self.numerify("############"))
        control = self.calculate_control_code(cups16)
        return self.evaluate_type(point_type, self.country_code, cups16, control)



# -*- coding: utf-8 -*-

from random import choice
from faker.providers import BaseProvider, ElementsType

localized = True


class EnergySupplier(BaseProvider):

	distributor: ElementsType[str] = ()
	country_code = "PT"

	def power_code(self):
		"""
		Returs a random code based on CUPS or EIC
		"""
		return self.country_code + str(self.random_element(7, True))


#!/usr/bin/env python
# -*- encoding: utf-8 -*-
from __future__ import absolute_import
from __future__ import print_function

from setuptools import setup, find_packages
from glob import glob
from os.path import splitext, basename, abspath, dirname, join

here = abspath(dirname(__file__))
try:
    README = open(join(here, 'README.md')).read()
except:
    README = 'An add-on provider for the Python Faker module to generate random CUPS (Universal Supply Point Code) or other useful topics for utilities sector processes. See ' \
             'https://github.com/xantygc/faker_utilities. '

CLASSIFIERS = [
    # complete classifier list: http://pypi.python.org/pypi?%3Aaction=list_classifiers
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Operating System :: Unix',
    'Operating System :: POSIX',
    'Operating System :: Microsoft :: Windows',
    'Programming Language :: Python',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
    'Topic :: Utilities',
]

setup(
    name='faker_utilities',
    version='0.0.2',
    license='MIT',
    description='Provider of energy & utilities topics data for Faker module',
    author='Santiago González',
    author_email='santiago.gonzalez.courel@gmail.com',
    url='https://github.com/xantygc/faker_utilities',
    long_description=README,
    packages=find_packages('energy_supplier'),
    package_dir={'': 'energy_supplier'},
    py_modules=[splitext(basename(path))[0] for path in glob('energy_supplier/*.py')],
    include_package_data=True,
    zip_safe=False,
    classifiers=CLASSIFIERS,
    project_urls={
        'Bug Tracker': 'https://github.com/xantygc/faker_utilities/issues',
    },
    python_requires='>=3.6',
    install_requires=['Faker>=8.2.1']
)